ShowPickerUtils class
选择框
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
formatModel(
PDuration p, DateMode modeS) → String? -
formatValue(
String label, dynamic list) → String -
hourFormat(
int val) → String -
showSingPicker(
{required BuildContext context, required List< Map< sourceList, String? selectLabel, required FormCallBackItem callResult, FormCallBackItem? callChange}) → voidString, dynamic> > -
showTimePicker(
{required BuildContext context, DateMode mode = DateMode.YMD, Suffix? suffix, PDuration? selectDate, PDuration? minDate, PDuration? maxDate, required FormCallBackItem callBackItem, FormCallBackItem? callBackChange}) → void